@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright (C) 2003-2017 The Music Player Daemon Project
+ * Copyright 2003-2018 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@ struct mpd_connection;
 
 int cmd_status(int argc, char **argv, struct mpd_connection *conn);
 int cmd_current(int argc, char **argv, struct mpd_connection *conn);
+int cmd_queued(int argc, char **argv, struct mpd_connection *conn);
 int cmd_play(int argc, char **argv, struct mpd_connection *conn);
 int cmd_searchplay(int argc, char **argv, struct mpd_connection *conn);
 int cmd_next(int argc, char **argv, struct mpd_connection *conn);
@@ -33,6 +34,7 @@ int cmd_pause(int argc, char **argv, struct mpd_connection *conn);
 int cmd_pause_if_playing(int argc, char **argv, struct mpd_connection *conn);
 int cmd_stop(int argc, char **argv, struct mpd_connection *conn);
 int cmd_seek(int argc, char **argv, struct mpd_connection *conn);
+int cmd_seek_through(int argc, char **argv, struct mpd_connection *conn);
 int cmd_clearerror(int argc, char **argv, struct mpd_connection *conn);
 int cmd_move(int argc, char **argv, struct mpd_connection *conn);
 int cmd_listall(int argc, char **argv, struct mpd_connection *conn);
