@@ -21,6 +21,7 @@
 */
 
 #include "queue.h"
+#include "tags.h"
 #include "args.h"
 #include "charset.h"
 #include "options.h"
@@ -120,17 +121,13 @@ cmd_del(int argc, char **argv, struct mpd_connection *conn)
 {
 	struct mpd_status *status = getStatus(conn);
 
-	const int plLength = mpd_status_get_queue_length(status);
+	const unsigned plLength = mpd_status_get_queue_length(status);
 
-	char *songsToDel = malloc(plLength);
-	memset(songsToDel,0,plLength);
+	bool *songsToDel = malloc(plLength);
+	memset(songsToDel, false, plLength);
 
-	for (int i = 0; i < argc; ++i) {
-		char *s;
-		if (argv[i][0]=='#')
-			s = &argv[i][1];
-		else
-			s = argv[i];
+	for (unsigned i = 0; i < (unsigned)argc; ++i) {
+		const char *const s = argv[i];
 
 		char *t;
 		int range[2];
@@ -149,7 +146,7 @@ cmd_del(int argc, char **argv, struct mpd_connection *conn)
 			range[1] = strtol(t+1, &t2, 10);
 			if(t + 1 == t2 || *t2!='\0')
 				DIE("error parsing range from: %s\n", argv[i]);
-		} else if (*t == ')' || *t=='\0')
+		} else if (*t=='\0')
 			range[1] = range[0];
 		else
 			DIE("error parsing song numbers from: %s\n", argv[i]);
@@ -166,18 +163,17 @@ cmd_del(int argc, char **argv, struct mpd_connection *conn)
 		if (range[1] < range[0])
 			DIE("song range must be from low to high: %i to %i\n",range[0],range[1]);
 
-		if (range[1] > plLength)
+		if ((unsigned)range[1] > plLength)
 			DIE("song number does not exist: %i\n",range[1]);
 
-		for (int j = range[0]; j <= range[1]; j++)
-			songsToDel[j - 1] = 1;
+		memset(songsToDel + range[0] - 1, true, range[1] - range[0] + 1);
 	}
 
 	if (!mpd_command_list_begin(conn, false))
 		printErrorAndExit(conn);
 
 	int songsDeleted = 0;
-	for (int i = 0; i < plLength; ++i) {
+	for (unsigned i = 0; i < plLength; ++i) {
 		if (songsToDel[i]) {
 			mpd_send_delete(conn, i - songsDeleted);
 			++songsDeleted;
@@ -195,6 +191,21 @@ cmd_del(int argc, char **argv, struct mpd_connection *conn)
 int
 cmd_playlist(int argc, char **argv, struct mpd_connection *conn)
 {
+	bool command_list = false;
+
+#if LIBMPDCLIENT_CHECK_VERSION(2,12,0)
+	/* ask MPD to omit the tags which are not used by the
+	   `--format` to reduce network transfer for tag values we're
+	   not going to use anyway (requires MPD 0.21 and libmpdclient
+	   2.12) */
+	if (mpd_connection_cmp_server_version(conn, 0, 21, 0) >= 0) {
+		if (!mpd_command_list_begin(conn, false) ||
+		    !send_tag_types_for_format(conn, options.format))
+			printErrorAndExit(conn);
+		command_list = true;
+	}
+#endif
+
 	bool ret = argc > 0
 		? mpd_send_list_playlist_meta(conn, argv[0])
 		: mpd_send_list_queue_meta(conn);
@@ -202,13 +213,10 @@ cmd_playlist(int argc, char **argv, struct mpd_connection *conn)
 	if (ret == false)
 		printErrorAndExit(conn);
 
-	struct mpd_song *song;
-	while ((song = mpd_recv_song(conn)) != NULL) {
-		pretty_print_song(song);
-		mpd_song_free(song);
-		printf("\n");
-	}
+	if (command_list && !mpd_command_list_end(conn))
+		printErrorAndExit(conn);
 
+	print_entity_list(conn, MPD_ENTITY_TYPE_SONG, true);
 	my_finishCommand(conn);
 	return 0;
 }
@@ -279,14 +287,31 @@ int cmd_insert (int argc, char ** argv, struct mpd_connection *conn )
 int
 cmd_prio(int argc, char **argv, struct mpd_connection *conn)
 {
+	char *endptr;
 	int i = 0;
-	const char *prio = argv[i++];
+	const char *s = argv[i++];
+	int prio = strtol(s, &endptr, 10);
+	if (endptr == s || *endptr != 0)
+		DIE("Failed to parse number: %s\n", s);
+	if (prio < 0 || prio > 255)
+		DIE("Priority must be between 0 and 255: %s\n", s);
 
 	if (!mpd_command_list_begin(conn, false))
 		printErrorAndExit(conn);
 
 	while (i < argc) {
-		if (!mpd_send_command(conn, "prio", prio, argv[i++], NULL))
+		s = argv[i++];
+		int position = strtol(s, &endptr, 10);
+		if (endptr == s || *endptr != 0)
+			DIE("Failed to parse number: %s\n", s);
+		if (position < 1)
+			DIE("Invalid song position: %s\n", s);
+
+		/* mpc's song positions are 1-based, but MPD uses
+		   0-based positions */
+		--position;
+
+		if (!mpd_send_prio(conn, prio, position))
 			break;
 	}
 
