@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright (C) 2003-2017 The Music Player Daemon Project
+ * Copyright 2003-2018 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,23 +25,6 @@
 
 struct mpd_connection;
 
-enum {
-	SEARCH_TAG_ANY = MPD_TAG_COUNT + 1,
-	SEARCH_TAG_URI = MPD_TAG_COUNT + 2,
-	SEARCH_TAG_BASE,
-};
-
-struct constraint {
-	enum mpd_tag_type type;
-	char *query;
-};
-
-enum mpd_tag_type
-get_search_type(const char *name);
-
-int
-get_constraints(int argc, char **argv, struct constraint **constraints);
-
 bool
 add_constraints(int argc, char ** argv, struct mpd_connection *conn);
 
